var indexSectionsWithContent =
{
  0: "_abcdefghiklmnopqrstuvwxyz~",
  1: "_abcdefghiklmnopqrstuvwz",
  2: "os",
  3: "abdehmnoprstv",
  4: "_abcdefghiklmnopqrstuvwxyz~",
  5: "_abcdefghiklmnopqrstuvwxyz",
  6: "_abcdefghiklmnopqrstuvwz",
  7: "abcdefgilmnopqrstuvw",
  8: "abcdefghiklmnopqrstuvwz",
  9: "abcdefgimoprstw",
  10: "_abcdeghimnopstw",
  11: "abcdeghilmoprstv",
  12: "abcdefghilmoprstuvwy"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "related",
  10: "defines",
  11: "groups",
  12: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Friends",
  10: "Macros",
  11: "Modules",
  12: "Pages"
};

